/*
 * Copyright (C) 2006 Jason Smith
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *
 */

/*!
 * @file log.h
 * @brief Declare some logging macros that behave differently on ipod and ipod-x11 builds.
 */

#ifndef LOG_H
#define LOG_H

/*!
 * Set to 1 or 0 to turn debug messages on or off (respectively).
 * Note that this only matters for the x11 build; The IPOD build
 * will always have debug disabled.
 */
#define DEBUG_ON    0

#if IPOD // building for the ipod
#	include <syslog.h>

#	define  DEBUG_LOG( fmt, args... )    {}
#	define  INFO_LOG(  fmt, args... )    {}
#	define  ERROR_LOG( fmt, args... )    syslog( LOG_ERR, fmt, ## args )
#	define  JFS_ASSERT( exp )            {}
#else // building for X11
#	if DEBUG_ON
#		define DEBUG_LOG( fmt, args... )     printf( fmt, ## args )
#	else
#		define DEBUG_LOG( fmt, args... )     {}
#	endif
#	define  INFO_LOG(  fmt, args... )        printf( fmt, ## args )
#	define  ERROR_LOG( fmt, args... )        printf( fmt, ## args )

#	include <unistd.h>
#	define  JFS_ASSERT( exp ) \
	{ \
		if( !(exp) ) \
		{ \
			ERROR_LOG( "*** ASSERTION FAILED ***\n  Expression='%s'\n  File='%s'\n  Func='%s'\n  Line=%i\n", \
				#exp, __FILE__, __func__, __LINE__ ); \
			_exit( 1 ); \
		} \
	}

#endif // IPOD

#endif // LOG_H

